Tract and Patch Search
=============================

To see the method and configuration in action, check out the
:doc:`/notebooks/tract_patch_search` notebook.

.. autofunction:: lsdb_rubin.tract_patch_search.tract_patch_search

.. autoclass:: lsdb_rubin.tract_patch_search.TractPatchSearch

    .. autofunction:: lsdb_rubin.tract_patch_search.TractPatchSearch.filter_hc_catalog

    .. autofunction:: lsdb_rubin.tract_patch_search.TractPatchSearch.search_points
